@@ -581,7 +581,7 @@ print("<h1>このUSBデバイス(".$org["nickname"].")は未登録です</h1>");
 <br>
 <input type="text" name=distaccount value="<?php echo $org["distaccount"]; ?>">コピー先PATHへのユーザ名、パスワード　USERNAME%PASSWORDと入力してください。必要ない場合も%のみ入力してください
 <br>
-<input type="text" name=docommand value="<?php echo $org["docommand"]; ?>">処理後に実行するコマンド  /usr/bin/micon -a bz_melody 960 C4 G4 C5 で音が鳴ります(KUROBOX)
+<input type="text" name=docommand value="<?php echo $org["docommand"]; ?>">処理後に実行するコマンド
 <br>
 <input type="submit">
 <input type="hidden" name="id" value="<?php echo $_var["id"]; ?>">
@@ -699,7 +699,11 @@ $flags = $org["flags"];
       print $_var["devname"]."\n";
       passthru("sleep 10");
       passthru("sudo mount ".$_var["devname"]." /mnt".$_var["devname"]);
-      passthru("sudo time usbsearchdelete /mnt".$_var["devname"]);
+      if ( 8 == ( 8 & flags )) {
+         passthru("sudo time usbsearchmove /mnt".$_var["devname"]);
+      } else {
+         passthru("sudo time usbsearchdelete /mnt".$_var["devname"]);
+      }
       passthru("sudo umount ".$_var["devname"]);
       print "</pre>";
   }
